@@ -26,7 +26,7 @@ from fakeredis._helpers import (
     null_terminate,
     Database,
 )
-from fakeredis.model import ZSet
+from fakeredis.model import ZSet, ExpiringMembersSet
 
 SORTED_SET_METHODS = {
     "ZUNIONSTORE": lambda s1, s2: s1 | s2,
@@ -114,19 +114,12 @@ class SortedSetCommandsMixin:
         return out
 
     @command((Key(ZSet), bytes, bytes), (bytes,))
-    def zadd(self, key, *args):
+    def zadd(self, key, *args) -> Union[int, None]:
         zset = key.value
 
         (nx, xx, ch, incr, gt, lt), left_args = extract_args(
             args,
-            (
-                "nx",
-                "xx",
-                "ch",
-                "incr",
-                "gt",
-                "lt",
-            ),
+            ("nx", "xx", "ch", "incr", "gt", "lt"),
             error_on_unexpected=False,
         )
 
@@ -189,7 +182,7 @@ class SortedSetCommandsMixin:
         return key.value.zcount(_min.lower_bound, _max.upper_bound)
 
     @command((Key(ZSet), Float, bytes))
-    def zincrby(self, key, increment, member):
+    def zincrby(self, key, increment, member) -> float:
         # Can't just default the old score to 0.0, because in IEEE754, adding
         # 0.0 to something isn't a nop (e.g., 0.0 + -0.0 == 0.0).
         try:
@@ -209,7 +202,7 @@ class SortedSetCommandsMixin:
     def zlexcount(self, key, _min, _max):
         return key.value.zlexcount(_min.value, _min.exclusive, _max.value, _max.exclusive)
 
-    def _zrangebyscore(self, key, _min, _max, reverse, withscores, offset, count) -> List[bytes]:
+    def _zrangebyscore(self, key, _min, _max, reverse, withscores, offset, count: int) -> List[bytes]:
         zset = key.value
         if reverse:
             _min, _max = _max, _min
@@ -257,33 +250,13 @@ class SortedSetCommandsMixin:
         count = -1 if count is None else count
 
         if bylex:
-            res = self._zrangebylex(
-                key,
-                StringTest.decode(start),
-                StringTest.decode(stop),
-                rev,
-                offset,
-                count,
-            )
+            res = self._zrangebylex(key, StringTest.decode(start), StringTest.decode(stop), rev, offset, count)
         elif byscore:
             res = self._zrangebyscore(
-                key,
-                ScoreTest.decode(start),
-                ScoreTest.decode(stop),
-                rev,
-                withscores,
-                offset,
-                count,
+                key, ScoreTest.decode(start), ScoreTest.decode(stop), rev, withscores, offset, count
             )
         else:
-            res = self._zrange(
-                key,
-                ScoreTest.decode(start),
-                ScoreTest.decode(stop),
-                rev,
-                withscores,
-                byscore,
-            )
+            res = self._zrange(key, ScoreTest.decode(start), ScoreTest.decode(stop), rev, withscores, byscore)
         return res
 
     @command((Key(ZSet), bytes, bytes), (bytes,))
@@ -332,17 +305,26 @@ class SortedSetCommandsMixin:
         count = -1 if count is None else count
         return self._zrangebyscore(key, _min, _max, True, withscores, offset, count)
 
-    @command((Key(ZSet), bytes))
-    def zrank(self, key, member):
+    @command(name="ZRANK", fixed=(Key(ZSet), bytes), repeat=(bytes,))
+    def zrank(self, key: CommandItem, member: bytes, *args: bytes) -> Union[None, int, List[Union[int, bytes]]]:
+        (withscore,), _ = extract_args(args, ("withscore",))
         try:
-            return key.value.rank(member)
+            rank, score = key.value.rank(member)
+            if withscore:
+                return [rank, self._encodefloat(score, False)]
+            return rank
         except KeyError:
             return None
 
-    @command((Key(ZSet), bytes))
-    def zrevrank(self, key, member):
+    @command(name="ZREVRANK", fixed=(Key(ZSet), bytes), repeat=(bytes,))
+    def zrevrank(self, key: CommandItem, member: bytes, *args: bytes) -> Union[None, int, List[Union[int, bytes]]]:
+        (withscore,), _ = extract_args(args, ("withscore",))
         try:
-            return len(key.value) - 1 - key.value.rank(member)
+            rank, score = key.value.rank(member)
+            rev_rank = len(key.value) - 1 - rank
+            if withscore:
+                return [rev_rank, self._encodefloat(score, False)]
+            return rev_rank
         except KeyError:
             return None
 
@@ -363,7 +345,7 @@ class SortedSetCommandsMixin:
 
     @command((Key(ZSet), ScoreTest, ScoreTest))
     def zremrangebyscore(self, key, _min, _max):
-        items = key.value.irange_score(_min.lower_bound, _max.upper_bound)
+        items = key.value.irange_score(_min.lower_bound, _max.upper_bound, reverse=False)
         return self.zrem(key, *[item[1] for item in items])
 
     @command((Key(ZSet), Int, Int))
@@ -374,7 +356,7 @@ class SortedSetCommandsMixin:
         return self.zrem(key, *[item[1] for item in items])
 
     @command((Key(ZSet), Int), (bytes, bytes))
-    def zscan(self, key, cursor, *args):
+    def zscan(self, key: CommandItem, cursor: int, *args: bytes) -> List[Union[int, List[bytes]]]:
         new_cursor, ans = self._scan(key.value.items(), cursor, *args)
         flat = []
         for key, score in ans:
@@ -383,7 +365,7 @@ class SortedSetCommandsMixin:
         return [new_cursor, flat]
 
     @command((Key(ZSet), bytes))
-    def zscore(self, key, member):
+    def zscore(self, key: CommandItem, member: bytes) -> Optional[bytes]:
         try:
             return self._encodefloat(key.value[member], False)
         except KeyError:
@@ -391,7 +373,7 @@ class SortedSetCommandsMixin:
 
     @staticmethod
     def _get_zset(value):
-        if isinstance(value, set):
+        if isinstance(value, ExpiringMembersSet):
             zset = ZSet()
             for item in value:
                 zset[item] = 1.0
@@ -487,13 +469,7 @@ class SortedSetCommandsMixin:
     def zdiffstore(self, dest, numkeys, *args):
         return self._zunioninterdiff("ZDIFFSTORE", dest, numkeys, *args)
 
-    @command(
-        (
-            Int,
-            bytes,
-        ),
-        (bytes,),
-    )
+    @command((Int, bytes), (bytes,))
     def zdiff(self, numkeys, *args):
         withscores = casematch(b"withscores", args[-1])
         sets = args[:-1] if withscores else args
@@ -505,13 +481,7 @@ class SortedSetCommandsMixin:
             res = [t for t in res]
         return res
 
-    @command(
-        (
-            Int,
-            bytes,
-        ),
-        (bytes,),
-    )
+    @command((Int, bytes), (bytes,))
     def zunion(self, numkeys, *args):
         withscores = casematch(b"withscores", args[-1])
         sets = args[:-1] if withscores else args
@@ -541,14 +511,7 @@ class SortedSetCommandsMixin:
             res = [t for t in res]
         return res
 
-    @command(
-        name="ZINTERCARD",
-        fixed=(
-            Int,
-            bytes,
-        ),
-        repeat=(bytes,),
-    )
+    @command(name="ZINTERCARD", fixed=(Int, bytes), repeat=(bytes,))
     def zintercard(self, numkeys, *args):
         (limit,), left_args = extract_args(
             args,
@@ -621,13 +584,7 @@ class SortedSetCommandsMixin:
 
         return self._zmpop(args[:-1], count, casematch(args[-1], b"max"), False)
 
-    @command(
-        fixed=(
-            Timeout,
-            Int,
-        ),
-        repeat=(bytes,),
-    )
+    @command(fixed=(Timeout, Int), repeat=(bytes,))
     def bzmpop(self, timeout, numkeys: int, *args):
         if numkeys == 0:
             raise SimpleError(msgs.NUMKEYS_GREATER_THAN_ZERO_MSG)
