@@ -18,8 +18,8 @@ def _check_lua_module_supported() -> bool:
 
 
 @pytest_asyncio.fixture(scope="session")
-def real_redis_version() -> Tuple[str, Union[None, Tuple[int, ...]]]:
-    """Returns server's version or None if server is not running"""
+def real_server_details() -> Tuple[str, Union[None, Tuple[int, ...]]]:
+    """Returns server's version or exit if server is not running"""
     client = None
     try:
         client = redis.Redis("localhost", port=6390, db=2)
@@ -31,7 +31,7 @@ def real_redis_version() -> Tuple[str, Union[None, Tuple[int, ...]]]:
         server_version = _create_version(server_version) or (7,)
         return server_type, server_version
     except redis.ConnectionError as e:
-        pytest.exit(f"Redis is not running {e}")
+        pytest.exit(f"Real server is not running {e}")
         return "redis", (6,)
     finally:
         if hasattr(client, "close"):
@@ -39,18 +39,16 @@ def real_redis_version() -> Tuple[str, Union[None, Tuple[int, ...]]]:
 
 
 @pytest_asyncio.fixture(name="fake_server")
-def _fake_server(request, real_redis_version) -> fakeredis.FakeServer:
-    server_type, _ = real_redis_version
-    min_server_marker = request.node.get_closest_marker("min_server")
-    server_version = min_server_marker.args[0] if min_server_marker else "6.2"
+def _fake_server(request, real_server_details: Tuple[str, Tuple[int, ...]]) -> fakeredis.FakeServer:
+    server_type, server_version = real_server_details
     server = fakeredis.FakeServer(server_type=server_type, version=server_version)
     server.connected = request.node.get_closest_marker("disconnected") is None
     return server
 
 
 @pytest_asyncio.fixture
-def r(request, create_redis) -> redis.Redis:
-    rconn = create_redis(db=2)
+def r(request, create_connection: Callable[[int], redis.Redis]) -> redis.Redis:
+    rconn = create_connection(db=2)
     connected = request.node.get_closest_marker("disconnected") is None
     if connected:
         rconn.flushall()
@@ -69,7 +67,7 @@ def _marker_version_value(request, marker_name: str):
 
 
 @pytest_asyncio.fixture(
-    name="create_redis",
+    name="create_connection",
     params=[
         pytest.param("StrictRedis", marks=pytest.mark.real),
         pytest.param("FakeStrictRedis", marks=pytest.mark.fake),
@@ -77,7 +75,7 @@ def _marker_version_value(request, marker_name: str):
 )
 def _create_connection(request) -> Callable[[int], redis.Redis]:
     cls_name = request.param
-    server_type, server_version = request.getfixturevalue("real_redis_version")
+    server_type, server_version = request.getfixturevalue("real_server_details")
     if not cls_name.startswith("Fake") and not server_version:
         pytest.skip("Redis is not running")
     unsupported_server_types = request.node.get_closest_marker("unsupported_server_types")
@@ -112,9 +110,11 @@ def _create_connection(request) -> Callable[[int], redis.Redis]:
     params=[pytest.param("fake", marks=pytest.mark.fake), pytest.param("real", marks=pytest.mark.real)],
 )
 async def _req_aioredis2(request) -> redis.asyncio.Redis:
-    server_type, server_version = request.getfixturevalue("real_redis_version")
+    server_type, server_version = request.getfixturevalue("real_server_details")
     if request.param != "fake" and not server_version:
         pytest.skip("Redis is not running")
+
+    decode_responses = bool(request.node.get_closest_marker("decode_responses"))
     unsupported_server_types = request.node.get_closest_marker("unsupported_server_types")
     if unsupported_server_types and server_type in unsupported_server_types.args:
         pytest.skip(f"Server type {server_type} is not supported")
@@ -131,9 +131,9 @@ async def _req_aioredis2(request) -> redis.asyncio.Redis:
     fake_server: Optional[fakeredis.FakeServer]
     if request.param == "fake":
         fake_server = request.getfixturevalue("fake_server")
-        ret = fakeredis.FakeAsyncRedis(server=fake_server, lua_modules=lua_modules)
+        ret = fakeredis.FakeAsyncRedis(server=fake_server, lua_modules=lua_modules, decode_responses=decode_responses)
     else:
-        ret = redis.asyncio.Redis(host="localhost", port=6390, db=2)
+        ret = redis.asyncio.Redis(host="localhost", port=6390, db=2, decode_responses=decode_responses)
         fake_server = None
     if not fake_server or fake_server.connected:
         await ret.flushall()
