@@ -89,10 +89,10 @@ def test_script_help(r: redis.Redis):
         b"DEBUG (YES|SYNC|NO)",
         b"    Set the debug mode for subsequent scripts executed.",
         b"EXISTS <sha1> [<sha1> ...]",
-        b"    Return information about the existence of the scripts in the script cach" b"e.",
+        b"    Return information about the existence of the scripts in the script cache.",
         b"FLUSH [ASYNC|SYNC]",
         b"    Flush the Lua scripts cache. Very dangerous on replicas.",
-        b"    When called without the optional mode argument, the behavior is determin" b"ed by the",
+        b"    When called without the optional mode argument, the behavior is determined by the",
         b"    lazyfree-lazy-user-flush configuration directive. Valid modes are:",
         b"    * ASYNC: Asynchronously flush the scripts cache.",
         b"    * SYNC: Synchronously flush the scripts cache.",
@@ -113,10 +113,10 @@ def test_script_help73(r: redis.Redis):
         b"DEBUG (YES|SYNC|NO)",
         b"    Set the debug mode for subsequent scripts executed.",
         b"EXISTS <sha1> [<sha1> ...]",
-        b"    Return information about the existence of the scripts in the script cach" b"e.",
+        b"    Return information about the existence of the scripts in the script cache.",
         b"FLUSH [ASYNC|SYNC]",
         b"    Flush the Lua scripts cache. Very dangerous on replicas.",
-        b"    When called without the optional mode argument, the behavior is determin" b"ed by the",
+        b"    When called without the optional mode argument, the behavior is determined by the",
         b"    lazyfree-lazy-user-flush configuration directive. Valid modes are:",
         b"    * ASYNC: Asynchronously flush the scripts cache.",
         b"    * SYNC: Synchronously flush the scripts cache.",
@@ -442,9 +442,9 @@ def test_eval_flushdb(r: redis.Redis):
     assert val == 1
 
 
-def test_eval_flushall(r, create_redis):
-    r1 = create_redis(db=2)
-    r2 = create_redis(db=3)
+def test_eval_flushall(r, create_connection):
+    r1 = create_connection(db=2)
+    r2 = create_connection(db=3)
 
     r1["r1"] = "r1"
     r2["r2"] = "r2"
