@@ -221,6 +221,19 @@ def test_zrank(r: redis.Redis):
     assert r.zrank("foo", "three") == 2
 
 
+@pytest.mark.min_server("7.2")
+@testtools.run_test_if_redispy_ver("gt", "4.6")
+def test_zrank_redis7_2(r: redis.Redis):
+    r.zadd("foo", {"one": 1})
+    r.zadd("foo", {"two": 2})
+    r.zadd("foo", {"three": 3})
+    assert r.zrank("foo", "one") == 0
+    assert r.zrank("foo", "two") == 1
+    assert r.zrank("foo", "three") == 2
+    assert r.zrank("foo", "one", withscore=True) == [0, b"1"]
+    assert r.zrank("foo", "two", withscore=True) == [1, b"2"]
+
+
 def test_zrank_non_existent_member(r: redis.Redis):
     assert r.zrank("foo", "one") is None
 
@@ -344,6 +357,19 @@ def test_zrevrank(r: redis.Redis):
     assert r.zrevrank("foo", "three") == 0
 
 
+@pytest.mark.min_server("7.2")
+@testtools.run_test_if_redispy_ver("gt", "4.6")
+def test_zrevrank_redis7_2(r: redis.Redis):
+    r.zadd("foo", {"one": 1})
+    r.zadd("foo", {"two": 2})
+    r.zadd("foo", {"three": 3})
+    assert r.zrevrank("foo", "one") == 2
+    assert r.zrevrank("foo", "two") == 1
+    assert r.zrevrank("foo", "three") == 0
+    assert r.zrevrank("foo", "one", withscore=True) == [2, b"1"]
+    assert r.zrevrank("foo", "two", withscore=True) == [1, b"2"]
+
+
 def test_zrevrank_non_existent_member(r: redis.Redis):
     assert r.zrevrank("foo", "one") is None
 
@@ -406,6 +432,8 @@ def test_zrangebyscore(r: redis.Redis):
     assert r.zrangebyscore("foo", "-inf", 1) == [b"zero"]
     assert r.zrangebyscore("foo", 2, "+inf") == [b"two", b"two_a_also", b"two_b_also", b"four"]
     assert r.zrangebyscore("foo", "-inf", "+inf") == [b"zero", b"two", b"two_a_also", b"two_b_also", b"four"]
+    assert r.zrangebyscore("foo", "-inf", "+inf", start=-1, num=3) == []
+    assert r.zrangebyscore("foo", "-inf", "+inf", start=0, num=2) == [b"zero", b"two"]
 
 
 def test_zrangebysore_exclusive(r: redis.Redis):
@@ -416,6 +444,7 @@ def test_zrangebysore_exclusive(r: redis.Redis):
     assert r.zrangebyscore("foo", "(0", 6) == [b"two", b"four", b"five"]
     assert r.zrangebyscore("foo", "(2", "(5") == [b"four"]
     assert r.zrangebyscore("foo", 0, "(4") == [b"zero", b"two"]
+    assert r.zrangebyscore("foo", 0.0, 4, start=-1, num=2) == []
 
 
 def test_zrangebyscore_raises_error(r: redis.Redis):
@@ -1153,3 +1182,12 @@ def test_bzmpop(r: redis.Redis):
     res = [b"b", [[b"b1", b"10"]]]
     assert r.bzmpop(0, "2", ["b", "a"], max=True) == res
     assert r.bzmpop(1, "2", ["foo", "bar"], max=True) is None
+
+
+# TODO https://github.com/redis/redis/issues/13952
+# def test_zrangebyscore_negative_start_after_sort(r: redis.Redis):
+#     r.zadd("A", {"A": 0.0})
+#     r.zadd("B", {"A": 0.0})
+#     with pytest.raises(redis.ResponseError):
+#         r.sort("B")
+#     assert r.zrangebyscore("B", 0.0, 0.0, start=-1, num=1) == [b"A"]
