@@ -4,6 +4,7 @@ from typing import List
 
 import pytest
 import redis
+from redis import ResponseError
 
 from fakeredis import _msgs as msgs
 from test import testtools
@@ -315,7 +316,7 @@ def test_xgroup_destroy(r: redis.Redis):
 
 
 @pytest.mark.max_server("6.3")
-def test_xgroup_create_redis6(r: redis.Redis):
+def test_xgroup_create_connection6(r: redis.Redis):
     stream, group = "stream", "group"
     message_id = r.xadd(stream, {"foo": "bar"})
     r.xgroup_create(stream, group, message_id)
@@ -329,7 +330,7 @@ def test_xgroup_create_redis6(r: redis.Redis):
 
 
 @pytest.mark.min_server("7")
-def test_xgroup_create_redis7(r: redis.Redis):
+def test_xgroup_create_connection7(r: redis.Redis):
     stream, group = "stream", "group"
     message_id = r.xadd(stream, {"foo": "bar"})
     r.xgroup_create(stream, group, message_id)
@@ -775,7 +776,7 @@ def test_xclaim(r: redis.Redis):
     ]
 
 
-def test_xread_blocking(create_redis):
+def test_xread_blocking(create_connection):
     # thread with xread block 0 should hang
     # putting data in the stream should unblock it
     event = threading.Event()
@@ -784,13 +785,13 @@ def test_xread_blocking(create_redis):
     def thread_func():
         while not event.is_set():
             time.sleep(0.1)
-        r = create_redis(db=1)
+        r = create_connection(db=1)
         r.xadd("stream", {"x": "1"})
         time.sleep(0.1)
 
     t = threading.Thread(target=thread_func)
     t.start()
-    r1 = create_redis(db=1)
+    r1 = create_connection(db=1)
     event.set()
     result = r1.xread({"stream": "$"}, block=0, count=1)
     event.clear()
@@ -812,3 +813,38 @@ def test_stream_ttl(r: redis.Redis):
     assert r.xread(streams={stream: 0}) == expected
     assert r.xtrim(stream, 0) == 1
     assert r.ttl(stream) == -1
+
+
+def test_xreadgroup_length_less_than_count(r: redis.Redis):
+    r.xadd("test-events", {"message": "hello"})
+    r.xadd("test-events", {"message": "bye"})
+
+    r.xgroup_create("test-events", "group1", id="0", mkstream=True)
+    messages = r.xreadgroup(
+        groupname="group1", consumername="consumer1", streams={"test-events": ">"}, count=10, block=2000
+    )
+    assert len(messages) == 1
+
+
+def test_xadd_change_time(r: redis.Redis):
+    res = r.xadd("foobar", {"a": "1"})
+    ts, seq = res.decode().split("-")
+    new_ts = int(ts) - 10
+    new_id = f"{new_ts}-*"
+    with pytest.raises(ResponseError):
+        r.xadd("foobar", {"a": "2"}, id=new_id)
+
+
+def test_xinfo_groups_pending(r: redis.Redis):
+    stream_name = "testing_stream"
+    group_name = "testing_group"
+    consumer_name = "testing_consumer"
+
+    r.delete(stream_name)
+    r.xgroup_create(stream_name, group_name, id="0", mkstream=True)
+
+    r.xadd(stream_name, {"key": "value"})
+
+    r.xreadgroup(group_name, consumer_name, {stream_name: ">"}, count=1)
+    assert r.xpending(stream_name, group_name)["pending"] == 1
+    assert r.xinfo_groups(stream_name)[0]["pending"] == 1
